==> secretsmanager-1.60.0-sources.jar: software/amazon/awscdk/services/secretsmanager/AttachmentTargetType.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * The type of service or database that's being associated with the secret.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.432Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.AttachmentTargetType")
public enum AttachmentTargetType {
    /**
     * A database instance.
     * <p>
     * @deprecated use RDS_DB_INSTANCE instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    INSTANCE,
    /**
     * A database cluster.
     * <p>
     * @deprecated use RDS_DB_CLUSTER instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    CLUSTER,
    /**
     * AWS::RDS::DBProxy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    RDS_DB_PROXY,
    /**
     * AWS::Redshift::Cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    REDSHIFT_CLUSTER,
    /**
     * AWS::DocDB::DBInstance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    DOCDB_DB_INSTANCE,
    /**
     * AWS::DocDB::DBCluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    DOCDB_DB_CLUSTER,
}

==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/AttachmentTargetType.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * The type of service or database that's being associated with the secret.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.660Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.AttachmentTargetType")
public enum AttachmentTargetType {
    /**
     * (deprecated) A database instance.
     * <p>
     * @deprecated use RDS_DB_INSTANCE instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    INSTANCE,
    /**
     * (deprecated) A database cluster.
     * <p>
     * @deprecated use RDS_DB_CLUSTER instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    CLUSTER,
    /**
     * AWS::RDS::DBProxy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    RDS_DB_PROXY,
    /**
     * AWS::Redshift::Cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    REDSHIFT_CLUSTER,
    /**
     * AWS::DocDB::DBInstance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    DOCDB_DB_INSTANCE,
    /**
     * AWS::DocDB::DBCluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    DOCDB_DB_CLUSTER,
}
